﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Linq;
using System.Windows.Forms;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Core.Views;
using HeuristicLab.Data;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;
using HeuristicLab.Optimization;
using HeuristicLab.Problems.DataAnalysis;

namespace HeuristicLab.DataPreprocessing {
  [View("Data Preprocessing View")]
  [Content(typeof(IPreprocessingContext), false)]
  [Content(typeof(PreprocessingContext), true)]
  public partial class DataPreprocessingView : ItemView {

    public new IPreprocessingContext Content {
      get { return (IPreprocessingContext)base.Content; }
      set { base.Content = value; }
    }

    public DataPreprocessingView() {
      InitializeComponent();
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
    }

    private void button1_Click(object sender, System.EventArgs e) {

      IPreprocessingData Data = Content.Data;

      foreach (string variable in Data.VariableNames) {
        for (int j = 0; j < Data.Rows; j++) {
          // assume: all double
          Data.SetCell(variable, j, 1.0);
        }
      }

      MessageBox.Show("Success, now cloning... ");

      Dataset dataset = Data.ExportToDataset();
      var variables = new CheckedItemList<StringValue>(Data.VariableNames.Select(s => new StringValue(s))).AsReadOnly();

      var cloner = new Cloner();

      cloner.RegisterClonedObject(Content.DataAnalysisProblemData.Dataset, dataset);
      cloner.RegisterClonedObject(Content.DataAnalysisProblemData.TrainingPartition, Data.TrainingPartition);
      cloner.RegisterClonedObject(Content.DataAnalysisProblemData.TestPartition, Data.TestPartition);
      cloner.RegisterClonedObject(Content.DataAnalysisProblemData.InputVariables, variables);
      if (Content.Algorithm != null) {
        cloner.RegisterClonedObject(Content.Algorithm.Runs, new RunCollection { OptimizerName = Content.Algorithm.Name });
      }

      var item = cloner.Clone(Content.ParentItem);
      MainFormManager.MainForm.ShowContent(item);
    }
  }
}
