﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace HeuristicLab.DataPreprocessing {
  class SearchLogic : ISearchLogic {
    private readonly IPreprocessingData preprocessingData;

    public SearchLogic(IPreprocessingData thePreprocessingData) {
      preprocessingData = thePreprocessingData;
    }

    public IDictionary<string, IEnumerable<int>> GetMissingValueIndices() {
      var dic = new Dictionary<string, IEnumerable<int>>();
      foreach (string variableName in preprocessingData.VariableNames) {
        dic.Add(variableName, GetMissingValueIndices(variableName));
      }
      return dic;
    }

    public bool IsMissingValue(string variableName, int rowIndex) {
      if (preprocessingData.IsType<double>(variableName)) {
        return double.IsNaN(preprocessingData.GetCell<double>(variableName, rowIndex));
      } else if (preprocessingData.IsType<string>(variableName)) {
        return string.IsNullOrEmpty(preprocessingData.GetCell<string>(variableName, rowIndex));
      } else if (preprocessingData.IsType<DateTime>(variableName)) {
        return preprocessingData.GetCell<DateTime>(variableName, rowIndex).Equals(DateTime.MinValue);
      } else {
        throw new ArgumentException("cell in column with variableName: " + variableName + " and row index " + rowIndex + " contains a non supported type.");
      }
    }

    public IEnumerable<int> GetMissingValueIndices(string variableName) {
      if (preprocessingData.IsType<double>(variableName)) {
        return preprocessingData.GetValues<double>(variableName).Select((s, i) => new { i, s }).Where(t => double.IsNaN(t.s)).Select(t => t.i);
      } else if (preprocessingData.IsType<string>(variableName)) {
        return preprocessingData.GetValues<string>(variableName).Select((s, i) => new { i, s }).Where(t => string.IsNullOrEmpty(t.s)).Select(t => t.i);
      } else if (preprocessingData.IsType<DateTime>(variableName)) {
        return preprocessingData.GetValues<DateTime>(variableName).Select((s, i) => new { i, s }).Where(t => t.s.Equals(DateTime.MinValue)).Select(t => t.i);
      } else {
        throw new ArgumentException("column with variableName: " + variableName + " contains a non supported type.");
      }
    }

  }
}
